import { __awaiter, __decorate, __metadata } from "tslib";
import { MdcComponent } from '@aurelia-mdc-web/base';
import { MDCLinearProgressFoundation } from '@material/linear-progress';
import { bindable } from 'aurelia-typed-observable-plugin';
import { useView, inject, PLATFORM, customElement } from 'aurelia-framework';
/**
 * @selector mdc-linear-progress
 */
let MdcLinearProgress = class MdcLinearProgress extends MdcComponent {
    progressChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            yield this.initialised;
            const determinate = this.progress !== undefined && !isNaN(this.progress);
            (_a = this.foundation) === null || _a === void 0 ? void 0 : _a.setDeterminate(determinate);
            if (determinate) {
                (_b = this.foundation) === null || _b === void 0 ? void 0 : _b.setProgress(this.progress);
            }
        });
    }
    bufferChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a;
            yield this.initialised;
            if (this.buffer !== undefined && !isNaN(this.buffer)) {
                (_a = this.foundation) === null || _a === void 0 ? void 0 : _a.setBuffer(this.buffer);
            }
        });
    }
    openChanged() {
        return __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            yield this.initialised;
            if (this.open) {
                (_a = this.foundation) === null || _a === void 0 ? void 0 : _a.open();
            }
            else {
                (_b = this.foundation) === null || _b === void 0 ? void 0 : _b.close();
            }
        });
    }
    // eslint-disable-next-line @typescript-eslint/require-await
    initialise() {
        return __awaiter(this, void 0, void 0, function* () {
            this.progressChanged();
            this.openChanged();
        });
    }
    getDefaultFoundation() {
        // DO NOT INLINE this variable. For backward compatibility, foundations take a Partial<MDCFooAdapter>.
        // To ensure we don't accidentally omit any methods, we need a separate, strongly typed adapter variable.
        const adapter = {
            addClass: (className) => {
                this.root.classList.add(className);
            },
            forceLayout: () => {
                this.root.getBoundingClientRect();
            },
            setBufferBarStyle: (styleProperty, value) => {
                const bufferBar = this.root.querySelector(MDCLinearProgressFoundation.strings.BUFFER_BAR_SELECTOR);
                if (bufferBar) {
                    bufferBar.style.setProperty(styleProperty, value);
                }
            },
            setPrimaryBarStyle: (styleProperty, value) => {
                const primaryBar = this.root.querySelector(MDCLinearProgressFoundation.strings.PRIMARY_BAR_SELECTOR);
                if (primaryBar) {
                    primaryBar.style.setProperty(styleProperty, value);
                }
            },
            hasClass: (className) => this.root.classList.contains(className),
            removeAttribute: (attributeName) => {
                this.root.removeAttribute(attributeName);
            },
            removeClass: (className) => {
                this.root.classList.remove(className);
            },
            setAttribute: (attributeName, value) => {
                this.root.setAttribute(attributeName, value);
            },
            setStyle: (name, value) => {
                this.root.style.setProperty(name, value);
            },
            attachResizeObserver: (callback) => {
                const RO = window.ResizeObserver;
                if (RO) {
                    const ro = new RO(callback);
                    ro.observe(this.root);
                    return ro;
                }
                return null;
            },
            getWidth: () => this.root.offsetWidth,
        };
        return new MDCLinearProgressFoundation(adapter);
    }
};
__decorate([
    bindable.number,
    __metadata("design:type", Number)
], MdcLinearProgress.prototype, "progress", void 0);
__decorate([
    bindable.number,
    __metadata("design:type", Number)
], MdcLinearProgress.prototype, "buffer", void 0);
__decorate([
    bindable.booleanAttr,
    __metadata("design:type", Boolean)
], MdcLinearProgress.prototype, "open", void 0);
MdcLinearProgress = __decorate([
    inject(Element),
    useView(PLATFORM.moduleName('./mdc-linear-progress.html')),
    customElement('mdc-linear-progress')
], MdcLinearProgress);
export { MdcLinearProgress };
//# sourceMappingURL=mdc-linear-progress.js.map